@@ -31,7 +31,7 @@ from telebox.telegram_bot.types.types.game_high_score import GameHighScore
 from telebox.telegram_bot.types.types.chat_member import ChatMember
 from telebox.telegram_bot.types.types.chat_member_owner import ChatMemberOwner
 from telebox.telegram_bot.types.types.chat_member_administrator import ChatMemberAdministrator
-from telebox.utils.not_set import NotSet
+from telebox.utils.not_set import NotSet, NOT_SET
 from telebox.context.utils import (
     get_event_chat_id,
     get_event_user_id,
@@ -55,7 +55,7 @@ class ContextTelegramBot:
         *,
         timeout_secs: Union[int, float, None] = None,
         with_reply: bool = False,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         entities: Optional[list[MessageEntity]] = None,
         disable_web_page_preview: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
@@ -122,7 +122,7 @@ class ContextTelegramBot:
         *,
         timeout_secs: Union[int, float, None] = None,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
         protect_content: Optional[bool] = None,
@@ -157,7 +157,7 @@ class ContextTelegramBot:
         timeout_secs: Union[int, float, None] = None,
         with_reply: bool = False,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
         protect_content: Optional[bool] = None,
@@ -190,7 +190,7 @@ class ContextTelegramBot:
         timeout_secs: Union[int, float, None] = None,
         with_reply: bool = False,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
         protect_content: Optional[bool] = None,
@@ -222,7 +222,7 @@ class ContextTelegramBot:
         timeout_secs: Union[int, float, None] = None,
         with_reply: bool = False,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         duration: Optional[int] = None,
         performer: Optional[str] = None,
@@ -263,7 +263,7 @@ class ContextTelegramBot:
         with_reply: bool = False,
         thumb: Union[InputFile, str, None] = None,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         disable_content_type_detection: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
@@ -302,7 +302,7 @@ class ContextTelegramBot:
         height: Optional[int] = None,
         thumb: Union[InputFile, str, None] = None,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         supports_streaming: Optional[bool] = None,
         disable_notification: Optional[bool] = None,
@@ -344,7 +344,7 @@ class ContextTelegramBot:
         height: Optional[int] = None,
         thumb: Union[InputFile, str, None] = None,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         disable_notification: Optional[bool] = None,
         protect_content: Optional[bool] = None,
@@ -380,7 +380,7 @@ class ContextTelegramBot:
         timeout_secs: Union[int, float, None] = None,
         with_reply: bool = False,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         duration: Optional[int] = None,
         disable_notification: Optional[bool] = None,
@@ -620,7 +620,7 @@ class ContextTelegramBot:
         allows_multiple_answers: Optional[bool] = None,
         correct_option_id: Optional[int] = None,
         explanation: Optional[str] = None,
-        explanation_parse_mode: Union[str, None, NotSet] = NotSet(),
+        explanation_parse_mode: Union[str, None, NotSet] = NOT_SET,
         explanation_entities: Optional[list[MessageEntity]] = None,
         open_period: Optional[int] = None,
         close_date: Optional[datetime] = None,
@@ -1125,7 +1125,7 @@ class ContextTelegramBot:
         message_id: Optional[int] = None,
         *,
         timeout_secs: Union[int, float, None] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         entities: Optional[list[MessageEntity]] = None,
         disable_web_page_preview: Optional[bool] = None,
         reply_markup: Optional[ReplyKeyboardMarkup] = None
@@ -1147,7 +1147,7 @@ class ContextTelegramBot:
         *,
         timeout_secs: Union[int, float, None] = None,
         caption: Optional[str] = None,
-        parse_mode: Union[str, None, NotSet] = NotSet(),
+        parse_mode: Union[str, None, NotSet] = NOT_SET,
         caption_entities: Optional[list[MessageEntity]] = None,
         reply_markup: Optional[InlineKeyboardMarkup] = None
     ) -> Message:
