@@ -1,9 +1,11 @@
+from .none import ErrorNoneFilter
 from .type import ErrorTypeFilter
 from .text import ErrorTextFilter
 from .reg_exp_text import ErrorRegExpTextFilter
 
 
 __all__ = [
+    "ErrorNoneFilter",
     "ErrorTypeFilter",
     "ErrorTextFilter",
     "ErrorRegExpTextFilter"
