@@ -1,9 +1,9 @@
 from .storage import AbstractStateStorage
-from .storages import MemoryStateStorage, FileStateStorage
+from .storages import MemoryStateStorage, JSONStateStorage
 
 
 __all__ = [
     "AbstractStateStorage",
     "MemoryStateStorage",
-    "FileStateStorage"
+    "JSONStateStorage"
 ]
