@@ -1,4 +1,4 @@
-from .not_set import NotSet
+from .not_set import NotSet, NOT_SET
 from .named_set import NamedSet
 from .callback_data_builders import AbstractCallbackDataBuilder
 from .task_executor import TaskExecutor
@@ -7,6 +7,7 @@ from .env import Env
 
 __all__ = [
     "NotSet",
+    "NOT_SET",
     "NamedSet",
     "AbstractCallbackDataBuilder",
     "TaskExecutor",
