@@ -3,7 +3,7 @@ from typing import Iterable, Union
 from telebox.utils.callback_data_builders.builder import AbstractCallbackDataBuilder
 
 
-FilterKey = str
+Key = str
 Value = Union[str, Iterable[str], None]
 
 
@@ -15,11 +15,11 @@ class SeparatoryCallbackDataBuilder(AbstractCallbackDataBuilder):
 
         self._separator = separator
 
-    def build(self, filter_key: FilterKey, value: Value = None) -> str:
-        if self._separator in filter_key:
-            raise ValueError(f"Filter key {filter_key!r} contains separator {self._separator!r}!")
+    def build(self, key: Key, value: Value = None) -> str:
+        if self._separator in key:
+            raise ValueError(f"Key {key!r} contains separator {self._separator!r}!")
 
-        data = filter_key
+        data = key
 
         if value is not None:
             if isinstance(value, str):
@@ -33,12 +33,12 @@ class SeparatoryCallbackDataBuilder(AbstractCallbackDataBuilder):
 
         return data
 
-    def parse(self, data: str) -> tuple[FilterKey, Value]:
-        filter_key, *value = data.split(self._separator)
+    def parse(self, data: str) -> tuple[Key, Value]:
+        key, *value = data.split(self._separator)
 
         if not value:
             value = None
         elif len(value) == 1:
             value = value[0]
 
-        return filter_key, value
+        return key, value
